:class:`~motor.motor_tornado.MotorCursor`
=========================================

.. currentmodule:: motor.motor_tornado

.. autoclass:: MotorCursor
  :members:


:class:`~motor.motor_tornado.MotorCommandCursor`
================================================

.. currentmodule:: motor.motor_tornado

.. autoclass:: MotorCommandCursor
  :members:
